"use client";

import { cn } from "@/common/utils";
import { getServer } from "mcutils-library";
import JavaMinecraftServer from "mcutils-library/dist/types/server/javaServer";
import { ServerPlatform } from "mcutils-library/dist/types/server/platform";
import Image from "next/image";
import { useState } from "react";
import { toast } from "react-toastify";
import { Button } from "./ui/button";
import { Card } from "./ui/card";
import { Input } from "./ui/input";

const defaultServerHostname = "play.hypixel.net";

export default function ServerSearch() {
  const [serverHostname, setServerHostname] = useState<string>(defaultServerHostname);
  const [server, setServer] = useState<JavaMinecraftServer | null>(null);

  const handleLookup = async () => {
    if (serverHostname === null || serverHostname.length <= 0) {
      toast.error("Please enter a server hostname");
      return;
    }
    try {
      const cachedServer = await getServer(ServerPlatform.Java, serverHostname);
      const { server } = cachedServer;
      setServer(server as JavaMinecraftServer);
    } catch (error) {
      toast.error("Unknown server");
      return;
    }
  };

  const handleKeyDown = (e: any) => {
    if (e.key === "Enter") {
      handleLookup();
    }
  };

  return (
    <div className="flex flex-col items-center gap-8">
      <div className="flex items-center gap-2">
        <Input
          className="w-[200px]"
          placeholder="Server Domain or IP"
          defaultValue={defaultServerHostname}
          onChange={(e) => setServerHostname(e.target.value)}
          onKeyDown={handleKeyDown}
        />
        <Button onClick={() => handleLookup()}>Lookup</Button>
      </div>

      {server && (
        <Card>
          <div className="flex flex-row gap-3 items-center">
            <Image src={server.favicon.url} alt="The server's Icon" width={64} height={64} />

            <div className={cn("flex flex-col gap-2")}>
              {server.motd.html.map((line, index) => {
                return <div key={index} dangerouslySetInnerHTML={{ __html: line }} />;
              })}
            </div>
          </div>

          <div className="flex flex-col gap-1">
            <div>
              <span className="font-bold">Host:</span> {server.hostname}
            </div>
            <div>
              <span className="font-bold">Players:</span> {server.players.online}/{server.players.max}
            </div>
          </div>
        </Card>
      )}
    </div>
  );
}
